<?php

// Set up the include/require handler
require_once( TEMPLATEPATH . '/lib/classes/it-utility.php' );

// Define needed theme global vars
$GLOBALS['theme_menu_var'] = 'ithemes-builder-theme';
$GLOBALS['theme_index'] = 'it-builder';

// Define the wp_content DIR for backward compatibility
if ( ! defined( 'WP_CONTENT_URL' ) )
	define( 'WP_CONTENT_URL', get_option( 'site_url' ) . '/wp-content' );
if ( ! defined( 'WP_CONTENT_DIR' ) )
	define( 'WP_CONTENT_DIR', ABSPATH . '/wp-content' );


// Add 2.9+ thumbnail support
if ( function_exists( 'add_theme_support' ) )
	add_theme_support( 'post-thumbnails' );


// Load needed parent class
ITUtility::require_file_once( 'lib/classes/it-core-class.php', 'ITCoreClass' );
ITUtility::require_file_once( 'default-layouts.php' );
ITUtility::require_file_once( 'lib/layout-engine/init.php' );

// Theme Options code
ITUtility::require_file_once( 'lib/theme-options/theme-options.php' );

// Billboard Code
ITUtility::require_file_once( 'lib/billboard/billboard.php' );

// Feedburner Widget Code
ITUtility::require_file_once( 'lib/feedburner-widget/feedburner-widget.php' );

// Load Builder Shortcodes
ITUtility::require_file_once( 'lib/shortcodes/shortcodes.php' );


// Certain code must be loaded at specific times
add_action( 'ithemes_load_plugins', 'ithemes_functions_after_init' );
function ithemes_functions_after_init() {
	// Include Tutorials Page
	ITUtility::require_file_once( 'lib/tutorials/tutorials.php' );
}

add_filter( 'it_filter_theme_menu_var', 'it_set_theme_menu_var' );
function it_set_theme_menu_var( $menu_var ) {
	return $GLOBALS['theme_menu_var'];
}

add_filter( 'it_storage_filter_theme_index', 'it_set_theme_index' );
function it_set_theme_index( $theme_index ) {
	return $GLOBALS['theme_index'];
}


// Now the text widget supports shortcodes
add_filter( 'widget_text', 'do_shortcode' );


// Apply SEO
add_action( 'builder_add_meta_data', 'builder_seo_options' );
function builder_seo_options() {
	global $post, $wp_theme_options;
	
	// build our excerpt
	if ( isset( $post ) ) {
		$post_content = ( strlen( strip_tags( $post->post_content ) ) <= 150) ? strip_tags($post->post_content) : substr(strip_tags($post->post_content),0,150);
		$post_excerpt = ( $post->post_excerpt ) ? $post->post_excerpt : $post_content;
		
		// set the description
		$description = (is_home()) ? get_bloginfo('description') : htmlspecialchars($post_excerpt);
		
		// get the tags
		$post_tags = '';
		if ( isset( $post ) && is_object( $post ) ) {
			$tags = get_the_tags( $post->ID );
			if ( ! empty( $tags ) && is_array( $tags ) ) {
				foreach( (array) $tags as $tag )
					if ( isset( $tag ) && is_object( $tag ) )
						$post_tags .= ','. $tag->name;
			}
			$post_tags = substr( $post_tags, 1 ); // removing the first "," from the list
		}
	}
	
	// add the follow code to our meta section
	echo "\n<!--To follow, or not to follow-->\n";
	if ( is_home() || is_single() || is_page() )
		echo "<meta name='robots' content='index,follow' />\n";
	else if ( ( 'no' !== $wp_theme_options['cat_index'] ) && is_category() )
		echo "<meta name='robots' content='index,follow' />\n";
	else if ( ! is_home() && ! is_single() && ! is_page() )
		echo "<meta name='robots' content='noindex,follow' />\n";
	
	// add the description and keyword code to our meta section
	echo "<!--Add Description and Keywords-->\n";
	if ( ( 'no' !== $wp_theme_options['tag_as_keyword'] ) && is_single() && ! empty( $post_tags ) )
		echo "<meta name='keywords' content='$post_tags' />\n";
	if ( is_home() || is_single() || is_page() )
		echo "<meta name='description' content='$description' />\n";
}

// Tracking/Analytics Code
function print_tracking() {
	global $wp_theme_options;
	
	if ( isset( $wp_theme_options['tracking'] ) )
		echo stripslashes( $wp_theme_options['tracking'] );
}
if ( isset( $wp_theme_options['tracking_pos'] ) && ( 'header' === $wp_theme_options['tracking_pos'] ) )
	add_action( 'wp_head', 'print_tracking' );
else // default
	add_action( 'builder_layout_engine_render_container_end', 'print_tracking', 20 );


if ( file_exists( dirname( __FILE__ ) . '/custom-functions.php' ) )
	ITUtility::require_file_once( dirname( __FILE__ ) . '/custom-functions.php' );

?>
