<?php

/*
Copyright 2009 iThemes (email: support@ithemes.com)

Written by Chris Jean
Version 1.0.1

Version History
	1.0.0 - 2009-07-14
		Release-ready
	1.0.1 - 2009-12-03
		Made code more robust by adding ITUtility check
*/


if ( ! class_exists( 'ITError' ) ) {
	if ( ! class_exists( 'ITUtility' ) )
		require_once( dirname( __FILE__ ) . '/it-utility.php' );
	if ( ! class_exists( 'ITStorage' ) )
		require_once( dirname( __FILE__ ) . '/it-storage.php' );
	
	class ITError {
		function fatal( $code, $message ) {
			
?>
	<div style="border:3px double red;padding:10px;margin:10px;font-size:12px;">
		<div style="color:red;font-weight:bold;font-size:20px;">Fatal Error</div>
		<br />
		
		<div>The theme has encountered a problem that it cannot recover from. Please use the following information to try to resolve the problem.</div>
		<br />
		
		<table style="font-size:12px;">
			<tr><td style="font-weight:bold;">Error Code:</td>
				<td><?php echo $code; ?></td>
			</tr>
			<tr><td style="font-weight:bold;">Message:</td>
				<td><?php echo $message; ?></td>
			</tr>
		</table>
		<br />
		
		<div>If you are unable to fix this problem, please copy all the text on this screen and send it to <a href="mailto:support@ithemes.com">support@ithemes.com</a>.</div>
		<br />
		
		<div><strong>Debug Data:</strong></div>
		<table style="font-size:10px;">
			<tr><td>Theme</td></tr>
		</table>
	</div>
<?php
			
			ITError::log( $code, $message, 'fatal' );
			
			exit;
		}
		
		function warn( $code, $message ) {
			ITUtility::show_error_message( $message );
			
			ITError::log( $code, $message, 'warning' );
		}
		
		function log( $code, $message, $type = 'warning' ) {
			if ( ! preg_match( '/^(warning|error|fatal)$/', $type ) )
				$type = 'warning';
			
			$store =& new ITStorage( 'ITError', true );
			
			$data = $store->load();
			
			$log = ITError::get_debug_data( $code );
			$log['message'] = $message;
			
			$data[] = $log;
			
			$store->save( $data );
		}
		
		function get_debug_data( $code ) {
			$data = array();
			
			// Implement this at some time... Add info about timestamp, theme, files, permissions, debug_backtrace, etc
			
			return $data;
		}
		
		function handle_error( $error_code, $error_message, $source_file, $source_line ) {
			if ( ( $error_code & ( E_ERROR | E_PARSE | E_CORE_ERROR | E_COMPILE_ERROR | E_USER_ERROR ) ) > 0 )
				ITError::fatal( "php_code_error:$error_code:$source_file:$source_line:$error_message", 'A fatal code error occurred.' );
		}
	}
	
	
	function it_error_shutdown() {
		$error = error_get_last();
		
		if ( is_array( $error ) )
			ITError::handle_error( $error['type'], $error['message'], $error['file'], $error['line'] );
	}
	
	
	if ( function_exists( 'error_get_last' ) )
		register_shutdown_function( 'it_error_shutdown' );
}
