<?php

/*
Written by Chris Jean for iThemes.com
Version 2.0.0

Version History
	1.0.4 - 2009-12-02
		Release ready
	2.0.0 - 2010-01-07
		Removed returned $post_id in save_data
*/


if ( ! class_exists( 'LayoutMetaBox' ) ) {
	class LayoutMetaBox {
		var $_var = 'layout-meta-box';
		
		
		function LayoutMetaBox() {
			add_action( 'admin_menu', array( &$this, 'add_meta_box' ) );
			add_action( 'save_post', array( &$this, 'save_data' ) );
		}
		
		function add_meta_box() {
			if ( function_exists( 'add_meta_box' ) ) {
				global $wp_version;
				
				$context = ( version_compare( $wp_version, '2.6.9', '>' ) ) ? 'side' : 'advanced';
				
				add_meta_box( 'layout_meta_box', 'Custom Layout', array( &$this, 'render_box' ), 'post', $context );
				add_meta_box( 'layout_meta_box', 'Custom Layout', array( &$this, 'render_box' ), 'page', $context );
			}
		}
		
		function render_box( $post ) {
			$layout_data = apply_filters( 'it_storage_load_layout_settings', array() );
			
			$layouts = array( '' => '' );
			foreach ( (array) $layout_data['layouts'] as $layout => $layout_data )
				$layouts[$layout] = $layout_data['description'];
			
			$type = ( preg_match( '|page[^/]+$|', $_SERVER['REQUEST_URI'] ) ) ? 'page' : 'post';
			
			$data = array( 'custom_layout' => get_post_meta( $post->ID, '_custom_layout', true ) );
			$form =& new ITForm( $data, array( 'prefix' => $this->_var ) );
			
?>
	<p><strong>Select a Layout:</strong></p>
	<p><?php $form->add_drop_down( 'custom_layout', $layouts ); ?></p>
	<p>Choosing a custom layout option here causes the chosen layout to be used for this <?php echo $type; ?>. It will override any custom layout views you have configured in the <a href="admin.php?page=layout-editor">Layout Editor</a>.</p>
<?php
			
		}
		
		function save_data( $post_id ) {
			if ( ! isset( $_POST['post_type'] ) )
				return;
			
			$type = ( 'page' === $_POST['post_type'] ) ? 'page' : 'post';
			if ( ! current_user_can( "edit_$type", $post_id ) )
				return;
			
			if ( ! empty( $_POST["{$this->_var}-custom_layout"] ) ) {
				if ( ! update_post_meta( $post_id, '_custom_layout', $_POST["{$this->_var}-custom_layout"] ) )
					add_post_meta( $post_id, '_custom_layout', $_POST["{$this->_var}-custom_layout"] );
			}
			else
				delete_post_meta( $post_id, '_custom_layout' );
		}
	}
	
	new LayoutMetaBox();
}


?>
