<?php

/*
Written by Chris Jean for iThemes.com
Version 3.0.3

Version History
	2.0.0 - 2009-12-08
		Complete rewrite
		This parent class now handles most redundant module functionality
	2.0.1 - 2009-12-08
		Fixed removed_wrappers label for reference
	2.0.2 - 2009-12-09
		Added test code for having more complex split code (currently
			commented out)
		Improved text output to be more generic with module references
		Updated sidebar registration code to handle new potential sidebar
			layouts and improved naming
	2.1.0 - 2009-12-10
		Completely restructured wrapper divs
	2.1.1 - 2009-12-11
		Changed outer wrapper widths to 100%
		Added the it_layout_engine_filter_sidebar_wrapper_attributes filter
		Added the following actions:
			it_layout_engine_module_start
			it_layout_engine_module_[module]_start
			it_layout_engine_module_end
			it_layout_engine_module_[module]_end
	2.1.2 - 2009-12-11
		Fixed sidebar names
	2.1.3 - 2010-01-05
		Changed register_layout_module to builder_register_layout_modules
		Changed layout_modules_enqueue_admin_scripts to builder_layout_modules_enqueue_admin_scripts
		Changed layout_modules_enqueue_admin_styles to builder_layout_modules_enqueue_admin_styles
	3.0.0 - 2010-01-07
		Major rewite
	3.0.1 - 2010-01-07
		Improved width filters
		
		builder_module_filter_width filter changed to builder_module_filter_widths and argument
			changed to $fields array with a widths array entry
		builder_module_filter_calculated_widths filter added to allow for filtering widths after
			all calculations have finished
	3.0.2 - 2010-01-10
		Added class_prefix to class names that weren't using it
		Pass $fields through _modify_module_inner_wrapper_fields if the module supplies it
		Standardized wrapper divs around sidebar contents
		Added .builder-module-sidebar-SIDEBAR-TYPE to sidebar wrapper
	3.0.3 - 2010-01-10
		Fixed sidebar registration/rendering naming for modules that allow more than one instance
*/



if ( ! class_exists( 'LayoutModule' ) ) {
	class LayoutModule {
		var $_name = 'Replace Me';
		var $_var = 'replace_me';
		var $_description = 'Replace this description.';
		var $_max = 0; // 0 or 1
		var $_editor_width = 300;
		var $_module_count = 1;
		var $_has_sidebars = true;
		var $_can_remove_wrappers = false;
		
		
		function LayoutModule() {
			add_action( 'builder_register_modules', array( &$this, 'register' ) );
			
			if ( ! empty( $_REQUEST['modify_module_settings'] ) )
				$module = $_REQUEST['modify_module_settings'];
			else if ( ! empty( $_REQUEST['add_module'] ) )
				$module = $_REQUEST['module'];
			
			
			if ( ! empty( $module ) && ( $module === $this->_var ) ) {
				add_action( 'builder_module_enqueue_admin_scripts', array( &$this, 'enqueue_admin_scripts' ) );
				add_action( 'builder_module_enqueue_admin_styles', array( &$this, 'enqueue_admin_styles' ) );
			}
		}
		
		function enqueue_admin_scripts( $url_base ) {
			if ( true === $this->_has_sidebars )
				wp_enqueue_script( "{$this->_var}-sidebar-script", "$url_base/js/sidebars.js" );
			
			if ( file_exists( dirname( __FILE__ ) . "/{$this->_var}/js/module.js" ) )
				wp_enqueue_script( "{$this->_var}-module-script", "$url_base/{$this->_var}/js/module.js" );
		}
		
		function enqueue_admin_styles( $url_base ) {
			// Meant to be overridden.
		}
		
		function register() {
			global $builder_modules;
			
			$builder_modules->register_module( $this );
		}
		
		function get_editor_width() {
			return $this->_editor_width;
		}
		
		function get_layout_option() {
			if ( true === $this->_has_sidebars )
				return 'sidebar';
			else
				return 'notused';
		}
		
		function get_defaults() {
			$defaults = array();
			
			if ( true === $this->_has_sidebars ) {
				$defaults['sidebar'] = '1_right';
				$defaults['sidebar_widths'] = '180';
				$defaults['custom_sidebar_widths'] = '';
			}
			if ( true === $this->_can_remove_wrappers )
				$defaults['remove_wrappers'] = '';
			
			if ( method_exists( &$this, '_get_defaults' ) )
				$defaults = $this->_get_defaults( $defaults );
			
			return $defaults;
		}
		
		function validate() {
			$result = array( 'data' => $_POST );
			
			if ( true === $this->_has_sidebars ) {
				if ( isset( $_POST['sidebar_widths'] ) && ( 'custom' === $_POST['sidebar_widths'] ) ) {
					$result['data']['custom_sidebar_widths'] = preg_replace( '/\s+/', '', $_POST['custom_sidebar_widths'] );
					
					$expected_widths = array(
						'none'		=> 0,
						'1_left'	=> 1,
						'2_left'	=> 2,
						'split'		=> 2,
						'1_right'	=> 1,
						'2_right'	=> 2,
						'split'		=> 2,
						'split_1_2'	=> 3,
						'split_2_1'	=> 3,
						'split_2_2'	=> 4,
					);
					
					$num_widths = count( explode( ',', $_POST['custom_sidebar_widths'] ) );
					
					if ( ( 1 === $expected_widths[$_POST['sidebar']] ) && ( 1 !== $num_widths ) )
						$result['errors'][] = 'You must supply a width for the sidebar';
					if ( $num_widths != $expected_widths[$_POST['sidebar']] )
						$result['errors'][] = "You must supply {$expected_widths[$_POST['sidebar']]} widths separated by commas";
					else if ( preg_match( '/[^0-9,\.]/', $result['data']['custom_sidebar_widths'] ) ) {
						$result['errors'][] = 'Only numbers can be used for sidebar widths';
					}
					else if ( array_sum( explode( ',', $result['data']['custom_sidebar_widths'] ) ) > ( $_POST['layout_width'] - 200 ) )
						$result['errors'][] = 'You must leave at least a 200 pixel area for the module content to render in. Please reduce the size of the sidebar widths.';
					else {
						foreach ( (array) explode( ',', $result['data']['custom_sidebar_widths'] ) as $width ) {
							if ( $width < 20 ) {
								$result['errors'][] = 'The minimum width for a sidebar is 20 pixels. Please ensure that all of your custom sidebar widths are 20 pixels or larger.';
								break;
							}
						}
					}
				}
			}
			
			if ( method_exists( &$this, '_validate' ) )
				$result = $this->_validate( $result );
			
			return $result;
		}
		
		function edit( $form, $results = true ) {
			if ( isset( $results['errors'] ) )
				$this->_print_errors( $results['errors'] );
			
			
			if ( method_exists( &$this, '_before_table_edit' ) )
				$this->_before_table_edit( $form, $results );
			
			echo "<table class='valign-top'>\n";
			
			if ( method_exists( &$this, '_start_table_edit' ) )
				$this->_start_table_edit( $form, $results );
			
			
			if ( true === $this->_has_sidebars ) {
				$sidebars = array(
					'none'		=> 'No Sidebars',
					'1_left'	=> '1 Left',
					'2_left'	=> '2 Left',
					'1_right'	=> '1 Right',
					'2_right'	=> '2 Right',
					'split'		=> 'Split (1 Left & 1 Right)',
/*					'split_1_2'	=> 'Split (1 Left & 2 Right)',
					'split_2_1'	=> 'Split (2 Left & 1 Right)',
					'split_2_2'	=> 'Split (2 Left & 2 Right)',*/
				);
				
				$default_widths = array(
					'none'		=> array(),
					'1_left'	=> array(
						'150'		=> 'Narrow (150px)',
						'180'		=> 'Standard (180px)',
						'200'		=> 'Wide (200px)',
						'custom'	=> 'Custom...',
					),
					'2_left'	=> array(
						'150,150'	=> 'Narrow/Narrow (150px/150px)',
						'150,180'	=> 'Narrow/Standard (150px/180px)',
						'150,200'	=> 'Narrow/Wide (150px/200px)',
						'180,150'	=> 'Standard/Narrow (180px/150px)',
						'180,180'	=> 'Standard/Standard (180px/180px)',
						'180,200'	=> 'Standard/Wide (180px/200px)',
						'200,150'	=> 'Wide/Narrow (200px/150px)',
						'200,180'	=> 'Wide/Standard (200px/180px)',
						'200,200'	=> 'Wide/Wide (200px/200px)',
						'custom'	=> 'Custom...',
					),
/*					'split_1_2'	=> array(
						'150,150,150'	=> 'Narrow/Narrow/Narrow (150px/150px/150px)',
						'150,150,180'	=> 'Narrow/Narrow/Standard (150px/150px/180px)',
						'150,180,150'	=> 'Narrow/Standard/Narrow (150px/180px/150px)',
						'150,180,180'	=> 'Narrow/Standard/Standard (150px/180px/180px)',
						'180,150,150'	=> 'Standard/Narrow/Narrow (180px/150px/150px)',
						'180,150,180'	=> 'Standard/Narrow/Standard (180px/150px/180px)',
						'180,180,150'	=> 'Standard/Standard/Narrow (180px/180px/150px)',
						'180,180,180'	=> 'Standard/Standard/Standard (180px/180px/180px)',
						'custom'	=> 'Custom...',
					),
					'split_2_2'	=> array(
						'150,150,150,150'	=> 'Default (150px/150px/150px/150px)',
						'custom'	=> 'Custom...',
					),*/
				);
				
				$default_widths['1_right'] = $default_widths['1_left'];
				$default_widths['2_right'] = $default_widths['2_left'];
				$default_widths['split'] = $default_widths['2_left'];
//				$default_widths['split_2_1'] = $default_widths['split_1_2'];
				
				if ( isset( $_REQUEST['sidebar'] ) && isset( $default_widths[$_REQUEST['sidebar']] ) )
					$starting_sidebar_widths = $default_widths[$_REQUEST['sidebar']];
				else
					$starting_sidebar_widths = null;
				
?>
	<tr><td><label for="sidebar">Sidebars</label></td>
		<td><?php $form->add_drop_down( 'sidebar', $sidebars ); ?></td>
	</tr>
	<tr id="sidebar-widths-row">
		<td>Sidebar&nbsp;Widths</td>
		<td>
			<?php $form->add_drop_down( 'sidebar_widths', null ); ?>
			<div id="sidebar-widths-custom" style="display:none;">
				<?php $form->add_text_box( 'custom_sidebar_widths', array( 'size' => '10', 'maxlength' => '20' ) ); ?><br />
				Specify the width of each sidebar in pixels.<br />
				For example, if you selected to have 2 Right sidebars and want to separate them into 170 pixel and 185 pixel widths, input <strong><code>170,185</code></strong> in the box above.
			</div>
		</td>
	</tr>
<?php
			}
			
			
			if ( method_exists( &$this, '_end_table_edit' ) )
				$this->_end_table_edit( $form, $results );
			
			if ( true === $this->_can_remove_wrappers ) {
				
?>
	<tr><td><label for="remove_wrappers">Remove&nbsp;Wrapper&nbsp;DIVs</label></td>
		<td>
			<?php $form->add_drop_down( 'remove_wrappers', array( '' => 'No', '1' => 'Yes' ) ); ?><br />
			<strong>Enabling this option is only recommended for advanced users as this can cause layout issues if not properly handled.</strong>
		</td>
	</tr>
<?php
				
			}
			
			echo "</table>\n";
			
			if ( method_exists( &$this, '_after_table_edit' ) )
				$this->_after_table_edit( $form, $results );
			
			
			if ( true === $this->_has_sidebars ) {
				
?>
	<div id="sidebar-widths-container" style="display:none;">
		<?php foreach ( (array) $default_widths as $id => $options ) : ?>
			<div id="sidebar-widths-container-<?php echo $id; ?>">
				<?php $form->add_drop_down( "sidebar-widths-$id", $options ); ?>
			</div>
		<?php endforeach; ?>
	</div>
	
	<script type="text/javascript">
		/* <![CDATA[ */
		init_module_sidebar_editor();
		/* ]]> */
	</script>
<?php
				
			}
			
			
			if ( isset( $_REQUEST['save'] ) )
				$form->add_hidden( 'had_error', '1' );
		}
		
		function _print_errors( $errors ) {
			if ( ! empty( $errors ) ) {
				foreach ( (array) $errors as $error )
					echo "<div id=\"message\" class=\"error\"><p><strong>$error</strong></p></div>\n";
				
				echo "<br />\n";
			}
		}
		
		function render( $fields ) {
			$fields = apply_filters( 'builder_module_filter_render_fields', $fields );
			
			$this->_data = $fields['data'];
			$this->_get_widths( $fields );
			
			do_action( 'builder_module_render_start', $fields );
			
			$this->_open_module_wrappers( $fields );
			$this->_render_sidebars( $fields, 'left' );
			$this->_render_element( $fields );
			$this->_render_sidebars( $fields, 'right' );
			$this->_close_module_wrappers( $fields );
			
			do_action( 'builder_module_render_end', $fields );
		}
		
		function _get_widths( $fields ) {
			$data = $fields['data'];
			
			
			$fields['widths']['container_width'] = apply_filters( 'builder_layout_engine_get_container_width', 0 );
			$fields['widths']['content_width'] = $fields['widths']['container_width'];
			$fields = apply_filters( 'builder_module_filter_widths', $fields );
			
			$this->_widths = $fields['widths'];
			$this->_widths['element_width'] = $fields['widths']['content_width'];
			$this->_widths['sidebar_widths'] = array();
			$this->_widths['full_sidebar_width'] = 0;
			
			if ( true === $this->_has_sidebars ) {
				if ( 'custom' !== $data['sidebar_widths'] )
					$this->_widths['sidebar_widths'] = explode( ',', $data['sidebar_widths'] );
				else
					$this->_widths['sidebar_widths'] = explode( ',', $data['custom_sidebar_widths'] );
				
				$this->_widths['full_sidebar_width'] = array_sum( (array) $this->_widths['sidebar_widths'] );
				
				$this->_widths['element_width'] = $this->_widths['content_width'] - $this->_widths['full_sidebar_width'];
			}
			
			$fields['widths'] = $this->_widths;
			$fields = apply_filters( 'builder_module_filter_calculated_widths', $fields );
			$this->_widths = $fields['widths'];
		}
		
		function _render_element( $fields ) {
			do_action( 'builder_module_render_element_start', $fields );
			
			$this->_open_element_wrappers( $fields );
			
			if ( method_exists( &$this, '_render' ) )
				$this->_render( $fields );
			
			$this->_close_element_wrappers( $fields );
			
			do_action( 'builder_module_render_element_end', $fields );
		}
		
		function _open_element_wrappers( $fields ) {
			$data = $fields['data'];
			
			if ( ( true !== $this->_can_remove_wrappers ) || ( empty( $data['remove_wrappers'] ) ) ) {
				do_action( 'builder_module_open_element_wrappers_start', $fields );
				
				if ( ( true !== $this->_has_sidebars ) || ( 'none' === $data['sidebar'] ) )
					$class = 'single';
				else if ( 'split' === $data['sidebar'] )
					$class = 'middle';
				else if ( preg_match( '/left/', $data['sidebar'] ) )
					$class = 'right';
				else
					$class = 'left';
				
				$fields['attributes'] = array( 'class' => array( "{$fields['class_prefix']}-block-outer-wrapper", $class, 'clearfix' ), 'style' => array( "width:{$this->_widths['element_width']}px;", 'overflow:hidden;' ) );
				$outer_wrapper_results = apply_filters( 'builder_module_filter_content_outer_wrapper_attributes', $fields );
				
				$fields['attributes'] = array( 'class' => array( "{$fields['class_prefix']}-block", "{$fields['class_prefix']}-element", 'clearfix' ) );
				$inner_wrapper_results = apply_filters( 'builder_module_filter_content_inner_wrapper_attributes', $fields );
				
				ITUtility::print_open_tag( 'div', $outer_wrapper_results['attributes'] );
				ITUtility::print_open_tag( 'div', $inner_wrapper_results['attributes'] );
				
				do_action( 'builder_module_close_element_wrappers_end', $fields );
			}
		}
		
		function _close_element_wrappers( $fields ) {
			if ( ( true !== $this->_can_remove_wrappers ) || ( empty( $fields['data']['remove_wrappers'] ) ) ) {
				do_action( 'builder_module_close_element_wrappers_start', $fields );
				
				echo "\n</div>\n</div>\n";
				
				do_action( 'builder_module_close_element_wrappers_end', $fields );
			}
		}
		
		function _open_module_wrappers( $fields ) {
			if ( ( true !== $this->_can_remove_wrappers ) || ( empty( $fields['data']['remove_wrappers'] ) ) ) {
				do_action( 'builder_module_open_module_wrappers_start', $fields );
				
				$this->_render_module_outer_wrapper( $fields );
				$this->_render_module_inner_wrapper( $fields );
				
				do_action( 'builder_module_open_module_wrappers_end', $fields );
			}
		}
		
		function _close_module_wrappers( $fields ) {
			if ( ( true !== $this->_can_remove_wrappers ) || ( empty( $fields['data']['remove_wrappers'] ) ) ) {
				do_action( 'builder_module_close_module_wrappers_start', $fields );
				
				echo "\n</div>\n</div>\n";
				
				do_action( 'builder_module_close_module_wrappers_end', $fields );
			}
		}
		
		function _render_module_outer_wrapper( $fields ) {
			$fields['attributes'] = $fields['outer_wrapper'];
			$fields['attributes']['style'] = array( "width:{$this->_widths['container_width']}px;", 'padding:0;', 'margin:0 auto;' , 'display:block;', 'clear:both;', 'overflow:hidden;' );
			
			$results = apply_filters( 'builder_module_filter_outer_wrapper_attributes', $fields );
			
			ITUtility::print_open_tag( 'div', $results['attributes'] );
		}
		
		function _render_module_inner_wrapper( $fields ) {
			$fields['attributes'] = $fields['inner_wrapper'];
			
			if ( method_exists( $this, '_modify_module_inner_wrapper_fields' ) )
				$fields = $this->_modify_module_inner_wrapper_fields( $fields );
			
			$results = apply_filters( 'builder_module_filter_inner_wrapper_attributes', $fields );
			
			ITUtility::print_open_tag( 'div', $results['attributes'] );
			
			$this->_module_count++;
		}
		
		function _render_sidebars( $fields, $side ) {
			do_action( 'builder_module_render_sidebars_start', $fields, $side );
			
			$data = $fields['data'];
			$layout = $fields['layout'];
			
			if ( true === $this->_has_sidebars ) {
				if ( 'none' === $data['sidebar'] )
					return;
				
				if ( empty( $data['sidebar_widths'] ) )
					ITError::fatal( 'empty_var:parameter:data[\'sidebar_widths\']', 'Unable to decide widths due to missing sidebar_widths value.' );
				
				$sidebar_name_prefix = "$layout - {$this->_name}";
				
				if ( 1 !== $this->_max )
					$sidebar_name_prefix .= " - {$fields['id']}";
				
				if ( "2_$side" === $data['sidebar'] ) {
					$this->_open_sidebar_wrappers( $fields, $side, $this->_widths['full_sidebar_width'] );
					
					echo "<div style='clear:both; width:{$this->_widths['full_sidebar_width']}; overflow:hidden;'>\n";
					$this->_render_sidebar( $fields, "$sidebar_name_prefix - Top Sidebar", array( 'class' => array( 'widget-wrapper', 'widget-wrapper-single', 'wideget-wrapper-top', 'single' ) ) );
					echo "</div>\n";
					
					echo "<div style='float:left; width:{$this->_widths['sidebar_widths'][0]}px; overflow:hidden;'>\n";
					$this->_render_sidebar( $fields, "$sidebar_name_prefix - Left Sidebar", array( 'class' => array( 'left', 'widget-wrapper', 'widget-wrapper-left', 'left' ) ) );
					echo "</div>\n";
					
					echo "<div style='float:right; width:{$this->_widths['sidebar_widths'][1]}px; overflow:hidden;'>\n";
					$this->_render_sidebar( $fields, "$sidebar_name_prefix - Right Sidebar", array( 'class' => array( 'right', 'widget-wrapper', 'widget-wrapper-right', 'right' ) ) );
					echo "</div>\n";
					
					echo "<div style='clear:both; width:{$this->_widths['full_sidebar_width']}; overflow:hidden;'>\n";
					$this->_render_sidebar( $fields, "$sidebar_name_prefix - Bottom Sidebar", array( 'class' => array( 'widget-wrapper', 'widget-wrapper-single', 'widget-wrapper-bottom', 'single' ) ) );
					echo "</div>\n";
					
					$this->_close_sidebar_wrappers( $fields );
				}
				else if ( preg_match( "/^(1_$side|split)$/", $data['sidebar'] ) ) {
					if ( 'left' === $side )
						$width = $this->_widths['sidebar_widths'][0];
					else
						$width = ( '1_right' === $data['sidebar'] ) ? $this->_widths['sidebar_widths'][0] : $this->_widths['sidebar_widths'][1];
					
					$this->_open_sidebar_wrappers( $fields, $side, $width );
					
					$this->_render_sidebar( $fields, "$sidebar_name_prefix - " . ucfirst( $side ) . ' Sidebar', array( 'class' => array( 'left', 'widget-wrapper', 'widget-wrapper-single', 'single' ) ) );
					
					$this->_close_sidebar_wrappers( $fields );
				}
			}
			
			do_action( 'builder_module_render_sidebars_end', $fields );
		}
		
		function _open_sidebar_wrappers( $fields, $side, $width ) {
			do_action( 'builder_module_open_sidebar_wrappers_start', $fields, $side, $width );
			
			$sidebar_type = str_replace( '_', '-', $fields['data']['sidebar'] );
			
			$fields['attributes'] = array( 'class' => array( "{$fields['class_prefix']}-block-outer-wrapper", $side ), 'style' => array( "width:{$width}px;", 'overflow:hidden;' ) );
			$outer_wrapper_results = apply_filters( 'builder_module_filter_sidebar_outer_wrapper_attributes', $fields );
			
			$fields['attributes'] = array( 'class' => array( "{$fields['class_prefix']}-block", "{$fields['class_prefix']}-sidebar", "{$fields['class_prefix']}-sidebar-$sidebar_type", 'sidebar', $side ) );
			$inner_wrapper_results = apply_filters( 'builder_module_filter_sidebar_inner_wrapper_attributes', $fields );
			
			ITUtility::print_open_tag( 'div', $outer_wrapper_results['attributes'] );
			ITUtility::print_open_tag( 'div', $inner_wrapper_results['attributes'] );
			
			do_action( 'builder_module_open_sidebar_wrappers_end', $fields, $side, $width );
		}
		
		function _close_sidebar_wrappers( $fields ) {
			do_action( 'builder_module_close_sidebar_wrappers_start', $fields );
			
			echo "\n</div>\n</div>\n";
			
			do_action( 'builder_module_close_sidebar_wrappers_end', $fields );
		}
		
		function _render_sidebar( $fields, $name, $attributes ) {
			$fields['sidebar_name'] = $name;
			$fields['attributes'] = $attributes;
			
			$results = apply_filters( 'builder_module_filter_sidebar_wrapper_attributes', $fields );
			
			ITUtility::print_open_tag( 'div', $results['attributes'] );
			
			unset( $fields['attributes'] );
			do_action( 'builder_layout_engine_render_sidebar', $fields );
			
			echo "</div>\n";
		}
		
		function register_sidebars( $module_data, $id, $layout ) {
			$data = $module_data['data'];
			$guid = $module_data['guid'];
			
			if ( method_exists( &$this, '_register_sidebars' ) )
				$this->_register_sidebars( $module_data, $id, $layout );
			
			if ( true === $this->_has_sidebars ) {
				$sidebar_name_prefix = "$layout - {$this->_name}";
				
				if ( 1 !== $this->_max )
					$sidebar_name_prefix .= " - $id";
				
				if ( preg_match( '/^(split_1_2|split_2_1|split_2_2)$/', $data['sidebar'] ) ) {
					if ( 'split_1_2' === $data['sidebar'] )
						$this->_register_sidebar( "$sidebar_name_prefix - Left Sidebar", $guid );
					else {
						$this->_register_sidebar( "$sidebar_name_prefix - Left - Top Sidebar", $guid );
						$this->_register_sidebar( "$sidebar_name_prefix - Left - Left Sidebar", $guid );
						$this->_register_sidebar( "$sidebar_name_prefix - Left - Right Sidebar", $guid );
						$this->_register_sidebar( "$sidebar_name_prefix - Left - Bottom Sidebar", $guid );
					}
					
					if ( 'split_2_1' === $data['sidebar'] )
						$this->_register_sidebar( "$sidebar_name_prefix - Right Sidebar", $guid );
					else {
						$this->_register_sidebar( "$sidebar_name_prefix - Right - Top Sidebar", $guid );
						$this->_register_sidebar( "$sidebar_name_prefix - Right - Left Sidebar", $guid );
						$this->_register_sidebar( "$sidebar_name_prefix - Right - Right Sidebar", $guid );
						$this->_register_sidebar( "$sidebar_name_prefix - Right - Bottom Sidebar", $guid );
					}
				}
				else {
					if ( preg_match( '/^(2_right|2_left)$/', $data['sidebar'] ) )
						$this->_register_sidebar( "$sidebar_name_prefix - Top Sidebar", $guid );
					
					if ( preg_match( '/^(1_left|2_right|2_left|split)$/', $data['sidebar'] ) )
						$this->_register_sidebar( "$sidebar_name_prefix - Left Sidebar", $guid );
					
					if ( preg_match( '/^(1_right|2_right|2_left|split)$/', $data['sidebar'] ) )
						$this->_register_sidebar( "$sidebar_name_prefix - Right Sidebar", $guid );
					
					if ( preg_match( '/^(2_right|2_left)$/', $data['sidebar'] ) )
						$this->_register_sidebar( "$sidebar_name_prefix - Bottom Sidebar", $guid );
				}
			}
		}
		
		function _register_sidebar( $name, $guid ) {
			$options = array();
			
			if ( is_array( $name ) )
				$options = array_merge( $options, $name );
			else
				$options['name'] = $name;
			
			if ( ! isset( $this->_guid_count[$guid] ) )
				$this->_guid_count[$guid] = 1;
			else
				$this->_guid_count[$guid]++;
			
			if ( empty( $options['id'] ) )
				$options['id'] = "$guid-{$this->_guid_count[$guid]}";
			
			do_action( 'builder_layout_engine_register_sidebar', $options );
		}
	}
	
	// The following line should be uncommented and updated for active modules.
//	new LayoutModule();
}


?>
